@@ -1,18 +1,30 @@
 from __future__ import annotations
 import asyncio
 from dataclasses import dataclass, field
+import decimal
 import inspect
 import json
 import sys
 import traceback
 import typing as t
 
+try:
+    from typing import get_args, get_origin  # type: ignore
+except ImportError:
+    # For Python 3.7 support
+    from typing_extensions import get_args, get_origin
+
 from docstring_parser import parse, Docstring, DocstringParam  # type: ignore
 
 from .format import Color, format_text, get_underline
 
 
-__VERSION__ = "0.1.9"
+__VERSION__ = "0.3.1"
+
+
+# If an annotation is one of these values, we will convert the string value
+# to it.
+CONVERTABLE_TYPES = (int, float, decimal.Decimal)
 
 
 @dataclass
@@ -26,6 +38,7 @@ class Command:
     command: t.Callable
     group_name: t.Optional[str] = None
     command_name: t.Optional[str] = None
+    aliases: t.List[str] = field(default_factory=list)
 
     def __post_init__(self):
         self.command_docstring: Docstring = parse(self.command.__doc__)
@@ -81,7 +94,7 @@ class Command:
         """
         output = []
 
-        for arg_name, annotation in self.annotations.items():
+        for arg_name, _ in self.annotations.items():
             arg_description = self._get_arg_description(arg_name=arg_name)
 
             arg_default = self._get_arg_default(arg_name=arg_name)
@@ -148,11 +161,21 @@ class Command:
             print(self.arguments_description)
         else:
             print("No args")
+
+        if self.aliases:
+            print("Aliases")
+            print(get_underline(7, character="-"))
+            alias_string = ", ".join(self.aliases)
+            print(format_text(alias_string, color=Color.green))
         print("")
 
     def call_with(self, arg_class: Arguments):
         """
         Call the command function with the given arguments.
+
+        The arguments are all strings at this point, as they're come from the
+        command line.
+
         """
         if arg_class.kwargs.get("help"):
             self.print_help()
@@ -160,23 +183,34 @@ class Command:
 
         annotations = t.get_type_hints(self.command)
 
-        kwargs = {}
+        kwargs = arg_class.kwargs.copy()
+        for index, value in enumerate(arg_class.args):
+            key = list(annotations.keys())[index]
+            kwargs[key] = value
 
-        for kwarg_key, kwarg_value in arg_class.kwargs.items():
-            annotation = annotations.get(kwarg_key)
+        cleaned_kwargs = {}
+
+        for key, value in kwargs.items():
+            annotation = annotations.get(key)
             # This only works with basic types like str at the moment.
-            if callable(annotation):
-                kwargs[kwarg_key] = annotation(kwarg_value)
 
-        for index, arg in enumerate(arg_class.args):
-            kwarg_key, annotation = list(annotations.items())[index]
-            if callable(annotation):
-                kwargs[kwarg_key] = annotation(arg)
+            if annotation in CONVERTABLE_TYPES:
+                value = annotation(value)
+            elif get_origin(annotation) is t.Union:
+                # t.Union is used to detect t.Optional
+                inner_annotations = get_args(annotation)
+                filtered = [i for i in inner_annotations if i is not None]
+                if len(filtered) == 1:
+                    annotation = filtered[0]
+                    if annotation in CONVERTABLE_TYPES:
+                        value = annotation(value)
+
+            cleaned_kwargs[key] = value
 
         if inspect.iscoroutinefunction(self.command):
-            asyncio.run(self.command(**kwargs))
+            asyncio.run(self.command(**cleaned_kwargs))
         else:
-            self.command(**kwargs)
+            self.command(**cleaned_kwargs)
 
 
 @dataclass
@@ -193,19 +227,6 @@ class CLI:
     description: str = "Targ CLI"
     commands: t.List[Command] = field(default_factory=list)
 
-    @property
-    def group_names(self) -> t.List[str]:
-        return [i.group_name for i in self.commands if i.group_name]
-
-    def command_exists(self, group_name: str, command_name: str) -> bool:
-        for command in self.commands:
-            if (
-                command.group_name == group_name
-                and command.command_name == command_name
-            ):
-                return True
-        return False
-
     def _validate_name(self, name: str) -> bool:
         """
         Any custom names provided by user should not contain spaces (i.e.
@@ -220,7 +241,7 @@ class CLI:
         command: t.Callable,
         group_name: t.Optional[str] = None,
         command_name: t.Optional[str] = None,
-        root=False,
+        aliases: t.List[str] = [],
     ):
         """
         Register a function or coroutine as a CLI command.
@@ -236,6 +257,8 @@ class CLI:
             By default, the name of the CLI command will be the same as the
             function or coroutine which is being called. You can override this
             here.
+        :param aliases:
+            The command can also be accessed using these aliases.
 
         """
         if group_name and not self._validate_name(group_name):
@@ -249,6 +272,7 @@ class CLI:
                 command=command,
                 group_name=group_name,
                 command_name=command_name,
+                aliases=aliases,
             )
         )
 
@@ -284,7 +308,10 @@ class CLI:
         self, command_name: str, group_name: t.Optional[str] = None
     ) -> t.Optional[Command]:
         for command in self.commands:
-            if command.command_name == command_name:
+            if (
+                command.command_name == command_name
+                or command_name in command.aliases
+            ):
                 if group_name and command.group_name != group_name:
                     continue
                 return command
