@@ -1,7 +1,7 @@
 from __future__ import annotations
 from enum import Enum
 
-import colorama
+import colorama  # type: ignore
 
 
 colorama.init()
